from eolymp.ecm import node_pb2 as _node_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ticket(_message.Message):
    __slots__ = ["created_at", "id", "locale", "message", "metadata", "secret", "status", "subject", "type", "updated_at", "user_email", "user_id"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Comment(_message.Message):
        __slots__ = ["created_at", "id", "message", "metadata", "updated_at", "user_email", "user_id"]
        class MetadataEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
        USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        created_at: _timestamp_pb2.Timestamp
        id: str
        message: _node_pb2.Node
        metadata: _containers.ScalarMap[str, str]
        updated_at: _timestamp_pb2.Timestamp
        user_email: str
        user_id: str
        def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., user_email: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    APPROVED: Ticket.Status
    AWAITING: Ticket.Status
    CLOSED: Ticket.Status
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    NONE: Ticket.Type
    PENDING: Ticket.Status
    QUESTION: Ticket.Type
    QUOTA_INCREASE: Ticket.Type
    REJECTED: Ticket.Status
    SECRET_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN: Ticket.Status
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    id: str
    locale: str
    message: _node_pb2.Node
    metadata: _containers.ScalarMap[str, str]
    secret: str
    status: Ticket.Status
    subject: str
    type: Ticket.Type
    updated_at: _timestamp_pb2.Timestamp
    user_email: str
    user_id: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[Ticket.Type, str]] = ..., user_id: _Optional[str] = ..., user_email: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., status: _Optional[_Union[Ticket.Status, str]] = ..., locale: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., secret: _Optional[str] = ..., subject: _Optional[str] = ..., message: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Category(_message.Message):
    __slots__ = ["descriptions", "id", "image", "index", "parent_id", "visible"]
    class Description(_message.Message):
        __slots__ = ["locale", "summary", "title"]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        locale: str
        summary: str
        title: str
        def __init__(self, locale: _Optional[str] = ..., title: _Optional[str] = ..., summary: _Optional[str] = ...) -> None: ...
    DESCRIPTIONS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    VISIBLE_FIELD_NUMBER: _ClassVar[int]
    descriptions: _containers.RepeatedCompositeFieldContainer[Category.Description]
    id: str
    image: str
    index: int
    parent_id: str
    visible: bool
    def __init__(self, id: _Optional[str] = ..., visible: bool = ..., index: _Optional[int] = ..., parent_id: _Optional[str] = ..., image: _Optional[str] = ..., descriptions: _Optional[_Iterable[_Union[Category.Description, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/keeper/blob.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/keeper/blob.proto\x12\reolymp.keeper\x1a!eolymp/annotations/resource.proto\"_\n\x04\x42lob\x12\x0b\n\x03\x65rn\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c:\x13\xb2\xe3\n\x0f\xba\xe3\n\x04\x62lob\xca\xe3\n\x03keyB/Z-github.com/eolymp/go-sdk/eolymp/keeper;keeperb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.keeper.blob_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/keeper;keeper'
  _BLOB._options = None
  _BLOB._serialized_options = b'\262\343\n\017\272\343\n\004blob\312\343\n\003key'
  _BLOB._serialized_start=78
  _BLOB._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/drive/file.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/drive/file.proto\x12\x0c\x65olymp.drive\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x02\n\x04\x46ile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\r\x12\x0c\n\x04type\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\nattributes\x18\x14 \x03(\x0b\x32\".eolymp.drive.File.AttributesEntry\x12\x0b\n\x03url\x18\x64 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/drive;driveb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.drive.file_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/drive;drive'
  _FILE_ATTRIBUTESENTRY._options = None
  _FILE_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _FILE._serialized_start=75
  _FILE._serialized_end=365
  _FILE_ATTRIBUTESENTRY._serialized_start=316
  _FILE_ATTRIBUTESENTRY._serialized_end=365
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RebuildScoreboardEvent(_message.Message):
    __slots__ = ["activity_id", "scoreboard_id", "space_id"]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_ID_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    activity_id: str
    scoreboard_id: str
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., scoreboard_id: _Optional[str] = ..., activity_id: _Optional[str] = ...) -> None: ...



from eolymp.executor import interactor_pb2 as _interactor_pb2
from eolymp.executor import verifier_pb2 as _verifier_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Task(_message.Message):
    __slots__ = ["constraints", "files", "interactor", "lang", "origin", "preconditions", "priority", "redirect_stderr_to_stdout", "reference", "runs", "runtime", "source", "use_file_io", "use_workspace_archive", "verifier"]
    class Constraint(_message.Message):
        __slots__ = ["actor", "cpu_time_limit", "file_size_limit", "memory_limit", "selector", "wall_time_limit"]
        ACTOR_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        actor: str
        cpu_time_limit: int
        file_size_limit: int
        memory_limit: int
        selector: _containers.RepeatedScalarFieldContainer[str]
        wall_time_limit: int
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., actor: _Optional[str] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ...) -> None: ...
    class File(_message.Message):
        __slots__ = ["path", "source_ern"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
        path: str
        source_ern: str
        def __init__(self, path: _Optional[str] = ..., source_ern: _Optional[str] = ...) -> None: ...
    class Precondition(_message.Message):
        __slots__ = ["depends_on", "max_execution_time", "selector", "stop_on_failure"]
        DEPENDS_ON_FIELD_NUMBER: _ClassVar[int]
        MAX_EXECUTION_TIME_FIELD_NUMBER: _ClassVar[int]
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        STOP_ON_FAILURE_FIELD_NUMBER: _ClassVar[int]
        depends_on: _containers.RepeatedScalarFieldContainer[str]
        max_execution_time: int
        selector: _containers.RepeatedScalarFieldContainer[str]
        stop_on_failure: bool
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., depends_on: _Optional[_Iterable[str]] = ..., stop_on_failure: bool = ..., max_execution_time: _Optional[int] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["answer_content", "answer_object_id", "cost", "debug", "index", "input_content", "input_object_id", "labels", "reference"]
        ANSWER_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ANSWER_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        DEBUG_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        answer_content: str
        answer_object_id: str
        cost: float
        debug: bool
        index: int
        input_content: str
        input_object_id: str
        labels: _containers.RepeatedScalarFieldContainer[str]
        reference: str
        def __init__(self, reference: _Optional[str] = ..., index: _Optional[int] = ..., debug: bool = ..., cost: _Optional[float] = ..., labels: _Optional[_Iterable[str]] = ..., input_object_id: _Optional[str] = ..., input_content: _Optional[str] = ..., answer_object_id: _Optional[str] = ..., answer_content: _Optional[str] = ...) -> None: ...
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PRECONDITIONS_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_STDERR_TO_STDOUT_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    USE_FILE_IO_FIELD_NUMBER: _ClassVar[int]
    USE_WORKSPACE_ARCHIVE_FIELD_NUMBER: _ClassVar[int]
    VERIFIER_FIELD_NUMBER: _ClassVar[int]
    constraints: _containers.RepeatedCompositeFieldContainer[Task.Constraint]
    files: _containers.RepeatedCompositeFieldContainer[Task.File]
    interactor: _interactor_pb2.Interactor
    lang: str
    origin: str
    preconditions: _containers.RepeatedCompositeFieldContainer[Task.Precondition]
    priority: int
    redirect_stderr_to_stdout: bool
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[Task.Run]
    runtime: str
    source: str
    use_file_io: bool
    use_workspace_archive: bool
    verifier: _verifier_pb2.Verifier
    def __init__(self, reference: _Optional[str] = ..., origin: _Optional[str] = ..., priority: _Optional[int] = ..., lang: _Optional[str] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., use_file_io: bool = ..., redirect_stderr_to_stdout: bool = ..., use_workspace_archive: bool = ..., preconditions: _Optional[_Iterable[_Union[Task.Precondition, _Mapping]]] = ..., constraints: _Optional[_Iterable[_Union[Task.Constraint, _Mapping]]] = ..., verifier: _Optional[_Union[_verifier_pb2.Verifier, _Mapping]] = ..., interactor: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ..., runs: _Optional[_Iterable[_Union[Task.Run, _Mapping]]] = ..., files: _Optional[_Iterable[_Union[Task.File, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Permission(_message.Message):
    __slots__ = ["problem_id", "role", "user_id"]
    class Role(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    EDITOR: Permission.Role
    NONE: Permission.Role
    OWNER: Permission.Role
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    role: Permission.Role
    user_id: str
    def __init__(self, problem_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[_Union[Permission.Role, str]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

CREATE_CONTEST: Entitlement
CREATE_SUBMISSION: Entitlement
CREATE_TICKET: Entitlement
DESCRIPTOR: _descriptor.FileDescriptor
LOOKUP_CONTEST: Entitlement
MANAGE_ANNOUNCEMENT: Entitlement
MANAGE_CONTEST: Entitlement
MANAGE_PARTICIPANT: Entitlement
MANAGE_PROBLEM: Entitlement
MANAGE_SUBMISSION: Entitlement
MANAGE_TICKET: Entitlement
NONE: Entitlement
VIEW_ANNOUNCEMENT: Entitlement
VIEW_PARTICIPANT: Entitlement
VIEW_PROBLEM: Entitlement
VIEW_REGISTRATION_FORM: Entitlement
VIEW_RUNTIME: Entitlement
VIEW_SUBMISSION: Entitlement
VIEW_TICKET: Entitlement

class Entitlement(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorLocalization(_message.Message):
    __slots__ = ["phrase_key", "phrase_params"]
    class PhraseParamsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    PHRASE_KEY_FIELD_NUMBER: _ClassVar[int]
    PHRASE_PARAMS_FIELD_NUMBER: _ClassVar[int]
    phrase_key: str
    phrase_params: _containers.ScalarMap[str, str]
    def __init__(self, phrase_key: _Optional[str] = ..., phrase_params: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ErrorReport(_message.Message):
    __slots__ = ["report_id"]
    REPORT_ID_FIELD_NUMBER: _ClassVar[int]
    report_id: str
    def __init__(self, report_id: _Optional[str] = ...) -> None: ...

class InvalidArgument(_message.Message):
    __slots__ = ["argument_path", "validation"]
    ARGUMENT_PATH_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_FIELD_NUMBER: _ClassVar[int]
    argument_path: str
    validation: _containers.RepeatedCompositeFieldContainer[Validation]
    def __init__(self, argument_path: _Optional[str] = ..., validation: _Optional[_Iterable[_Union[Validation, _Mapping]]] = ...) -> None: ...

class QuotaExceeded(_message.Message):
    __slots__ = ["quota", "usage"]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    quota: int
    usage: int
    def __init__(self, quota: _Optional[int] = ..., usage: _Optional[int] = ...) -> None: ...

class Validation(_message.Message):
    __slots__ = ["argument_path", "error_message", "localization"]
    ARGUMENT_PATH_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    LOCALIZATION_FIELD_NUMBER: _ClassVar[int]
    argument_path: _containers.RepeatedScalarFieldContainer[str]
    error_message: str
    localization: ErrorLocalization
    def __init__(self, argument_path: _Optional[_Iterable[str]] = ..., error_message: _Optional[str] = ..., localization: _Optional[_Union[ErrorLocalization, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/acl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65olymp/judge/acl.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\"\x7f\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x04role\x18\x02 \x01(\x0e\x32\x1d.eolymp.judge.Permission.Role\x12\x0f\n\x07user_id\x18\x03 \x01(\t\"\'\n\x04Role\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\n\n\x06VIEWER\x10\x02\"5\n\x14GrantPermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\x17\n\x15GrantPermissionOutput\"(\n\x15RevokePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x18\n\x16RevokePermissionOutput\"*\n\x17\x44\x65scribePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribePermissionOutput\x12,\n\npermission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Permission\"\x9a\x02\n\x14ListPermissionsInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListPermissionsInput.Filter\x1a\x95\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListPermissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Permission2\xb6\x04\n\x03\x41\x63l\x12\x89\x01\n\x0fGrantPermission\x12\".eolymp.judge.GrantPermissionInput\x1a#.eolymp.judge.GrantPermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x1a\x16/permissions/{user_id}\x12\x8c\x01\n\x10RevokePermission\x12#.eolymp.judge.RevokePermissionInput\x1a$.eolymp.judge.RevokePermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18*\x16/permissions/{user_id}\x12\x92\x01\n\x12\x44\x65scribePermission\x12%.eolymp.judge.DescribePermissionInput\x1a&.eolymp.judge.DescribePermissionOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x16/permissions/{user_id}\x12\x7f\n\x0fListPermissions\x12\".eolymp.judge.ListPermissionsInput\x1a#.eolymp.judge.ListPermissionsOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/permissionsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.acl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ACL.methods_by_name['GrantPermission']._options = None
  _ACL.methods_by_name['GrantPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\032\026/permissions/{user_id}'
  _ACL.methods_by_name['RevokePermission']._options = None
  _ACL.methods_by_name['RevokePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030*\026/permissions/{user_id}'
  _ACL.methods_by_name['DescribePermission']._options = None
  _ACL.methods_by_name['DescribePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\030\022\026/permissions/{user_id}'
  _ACL.methods_by_name['ListPermissions']._options = None
  _ACL.methods_by_name['ListPermissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\016\022\014/permissions'
  _PERMISSION._serialized_start=142
  _PERMISSION._serialized_end=269
  _PERMISSION_ROLE._serialized_start=230
  _PERMISSION_ROLE._serialized_end=269
  _GRANTPERMISSIONINPUT._serialized_start=271
  _GRANTPERMISSIONINPUT._serialized_end=324
  _GRANTPERMISSIONOUTPUT._serialized_start=326
  _GRANTPERMISSIONOUTPUT._serialized_end=349
  _REVOKEPERMISSIONINPUT._serialized_start=351
  _REVOKEPERMISSIONINPUT._serialized_end=391
  _REVOKEPERMISSIONOUTPUT._serialized_start=393
  _REVOKEPERMISSIONOUTPUT._serialized_end=417
  _DESCRIBEPERMISSIONINPUT._serialized_start=419
  _DESCRIBEPERMISSIONINPUT._serialized_end=461
  _DESCRIBEPERMISSIONOUTPUT._serialized_start=463
  _DESCRIBEPERMISSIONOUTPUT._serialized_end=535
  _LISTPERMISSIONSINPUT._serialized_start=538
  _LISTPERMISSIONSINPUT._serialized_end=820
  _LISTPERMISSIONSINPUT_FILTER._serialized_start=671
  _LISTPERMISSIONSINPUT_FILTER._serialized_end=820
  _LISTPERMISSIONSOUTPUT._serialized_start=822
  _LISTPERMISSIONSOUTPUT._serialized_end=901
  _ACL._serialized_start=904
  _ACL._serialized_end=1470
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/community.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import idp_pb2 as eolymp_dot_community_dot_idp__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/community/community.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a\x1a\x65olymp/community/idp.proto\x1a\x1d\x65olymp/community/member.proto\x1a!eolymp/wellknown/expression.proto\"N\n\x0eJoinSpaceInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"2\n\x0fJoinSpaceOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"E\n\x13RegisterMemberInput\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\"\x16\n\x14RegisterMemberOutput\"\x11\n\x0fLeaveSpaceInput\"\x12\n\x10LeaveSpaceOutput\":\n\x0e\x41\x64\x64MemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"2\n\x0f\x41\x64\x64MemberOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x83\x02\n\x11UpdateMemberInput\x12\x38\n\x05patch\x18\x01 \x03(\x0e\x32).eolymp.community.UpdateMemberInput.Patch\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12(\n\x06member\x18\x03 \x01(\x0b\x32\x18.eolymp.community.Member\"w\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0e\n\nREGISTERED\x10\x03\x12\t\n\x05GHOST\x10\x04\x12\x16\n\x12OUT_OF_COMPETITION\x10\x05\x12\x0e\n\nIDENTITIES\x10\x06\x12\n\n\x06VALUES\x10\x07\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\x17\n\x15IntrospectMemberInput\"B\n\x16IntrospectMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xf0\x03\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x1a\x81\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x08\x64isabled\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x39\n\ridentity_name\x18\n \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12=\n\x11identity_nickname\x18\x0b \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12:\n\x0eidentity_email\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"`\n\x16\x41\x64\x64MemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.eolymp.community.Member.Identity\".\n\x17\x41\x64\x64MemberIdentityOutput\x12\x13\n\x0bidentity_id\x18\x01 \x01(\t\"x\n\x19UpdateMemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x13\n\x0bidentity_id\x18\x02 \x01(\t\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.eolymp.community.Member.Identity\"\x1c\n\x1aUpdateMemberIdentityOutput\"C\n\x19RemoveMemberIdentityInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x13\n\x0bidentity_id\x18\x02 \x01(\t\"\x1c\n\x1aRemoveMemberIdentityOutput\"Z\n\x11\x41\x64\x64\x41ttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\"\n\x12\x41\x64\x64\x41ttributeOutput\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute\"\x1f\n\x1d\x44\x65scribeIdentityProviderInput\"v\n\x1e\x44\x65scribeIdentityProviderOutput\x12\x0f\n\x05local\x18\x01 \x01(\x08H\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x42\n\n\x08provider\"v\n\x1e\x43onfigureIdentityProviderInput\x12\x0f\n\x05local\x18\x01 \x01(\x08H\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x42\n\n\x08provider\"!\n\x1f\x43onfigureIdentityProviderOutput2\xd7\x19\n\tCommunity\x12\x94\x01\n\tJoinSpace\x12 .eolymp.community.JoinSpaceInput\x1a!.eolymp.community.JoinSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\"\x0e/members/_self\x12\x97\x01\n\nLeaveSpace\x12!.eolymp.community.LeaveSpaceInput\x1a\".eolymp.community.LeaveSpaceOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:join\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10*\x0e/members/_self\x12\xaf\x01\n\x0eRegisterMember\x12%.eolymp.community.RegisterMemberInput\x1a&.eolymp.community.RegisterMemberOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1b\"\x19/members/_self/attributes\x12\x8c\x01\n\x10IntrospectMember\x12\'.eolymp.community.IntrospectMemberInput\x1a(.eolymp.community.IntrospectMemberOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/members/_self\x12\x8f\x01\n\tAddMember\x12 .eolymp.community.AddMemberInput\x1a!.eolymp.community.AddMemberOutput\"=\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\"\x08/members\x12\xa4\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\"\x14/members/{member_id}\x12\xa4\x01\n\x0cRemoveMember\x12#.eolymp.community.RemoveMemberInput\x1a$.eolymp.community.RemoveMemberOutput\"I\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16*\x14/members/{member_id}\x12\xa9\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"H\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x16\x12\x14/members/{member_id}\x12\x94\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"<\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/members\x12\xbe\x01\n\x11\x41\x64\x64MemberIdentity\x12(.eolymp.community.AddMemberIdentityInput\x1a).eolymp.community.AddMemberIdentityOutput\"T\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02!\"\x1f/members/{member_id}/identities\x12\xd5\x01\n\x14UpdateMemberIdentity\x12+.eolymp.community.UpdateMemberIdentityInput\x1a,.eolymp.community.UpdateMemberIdentityOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x1a-/members/{member_id}/identities/{identity_id}\x12\xd5\x01\n\x14RemoveMemberIdentity\x12+.eolymp.community.RemoveMemberIdentityInput\x1a,.eolymp.community.RemoveMemberIdentityOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/*-/members/{member_id}/identities/{identity_id}\x12\x9b\x01\n\x0c\x41\x64\x64\x41ttribute\x12#.eolymp.community.AddAttributeInput\x1a$.eolymp.community.AddAttributeOutput\"@\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\"\x0b/attributes\x12\xb4\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\"\x1b/attributes/{attribute_key}\x12\xb4\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"P\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d*\x1b/attributes/{attribute_key}\x12\xb9\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"O\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\x12\x1b/attributes/{attribute_key}\x12\xa0\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"?\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\x12\x0b/attributes\x12\x9a\x01\n\x18\x44\x65scribeIdentityProvider\x12/.eolymp.community.DescribeIdentityProviderInput\x1a\x30.eolymp.community.DescribeIdentityProviderOutput\"\x1b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x06\x12\x04/idp\x12\xbb\x01\n\x19\x43onfigureIdentityProvider\x12\x30.eolymp.community.ConfigureIdentityProviderInput\x1a\x31.eolymp.community.ConfigureIdentityProviderOutput\"9\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x06\x1a\x04/idpB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.community_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _COMMUNITY.methods_by_name['JoinSpace']._options = None
  _COMMUNITY.methods_by_name['JoinSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020\"\016/members/_self'
  _COMMUNITY.methods_by_name['LeaveSpace']._options = None
  _COMMUNITY.methods_by_name['LeaveSpace']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:join\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\020*\016/members/_self'
  _COMMUNITY.methods_by_name['RegisterMember']._options = None
  _COMMUNITY.methods_by_name['RegisterMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\033\"\031/members/_self/attributes'
  _COMMUNITY.methods_by_name['IntrospectMember']._options = None
  _COMMUNITY.methods_by_name['IntrospectMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\020\022\016/members/_self'
  _COMMUNITY.methods_by_name['AddMember']._options = None
  _COMMUNITY.methods_by_name['AddMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\"\010/members'
  _COMMUNITY.methods_by_name['UpdateMember']._options = None
  _COMMUNITY.methods_by_name['UpdateMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\"\024/members/{member_id}'
  _COMMUNITY.methods_by_name['RemoveMember']._options = None
  _COMMUNITY.methods_by_name['RemoveMember']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026*\024/members/{member_id}'
  _COMMUNITY.methods_by_name['DescribeMember']._options = None
  _COMMUNITY.methods_by_name['DescribeMember']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\026\022\024/members/{member_id}'
  _COMMUNITY.methods_by_name['ListMembers']._options = None
  _COMMUNITY.methods_by_name['ListMembers']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/members'
  _COMMUNITY.methods_by_name['AddMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['AddMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002!\"\037/members/{member_id}/identities'
  _COMMUNITY.methods_by_name['UpdateMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['UpdateMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\032-/members/{member_id}/identities/{identity_id}'
  _COMMUNITY.methods_by_name['RemoveMemberIdentity']._options = None
  _COMMUNITY.methods_by_name['RemoveMemberIdentity']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/*-/members/{member_id}/identities/{identity_id}'
  _COMMUNITY.methods_by_name['AddAttribute']._options = None
  _COMMUNITY.methods_by_name['AddAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\"\013/attributes'
  _COMMUNITY.methods_by_name['UpdateAttribute']._options = None
  _COMMUNITY.methods_by_name['UpdateAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\"\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['RemoveAttribute']._options = None
  _COMMUNITY.methods_by_name['RemoveAttribute']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035*\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['DescribeAttribute']._options = None
  _COMMUNITY.methods_by_name['DescribeAttribute']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\022\033/attributes/{attribute_key}'
  _COMMUNITY.methods_by_name['ListAttributes']._options = None
  _COMMUNITY.methods_by_name['ListAttributes']._serialized_options = b'\202\343\n\031\212\343\n\025community:member:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\022\013/attributes'
  _COMMUNITY.methods_by_name['DescribeIdentityProvider']._options = None
  _COMMUNITY.methods_by_name['DescribeIdentityProvider']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\006\022\004/idp'
  _COMMUNITY.methods_by_name['ConfigureIdentityProvider']._options = None
  _COMMUNITY.methods_by_name['ConfigureIdentityProvider']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\006\032\004/idp'
  _JOINSPACEINPUT._serialized_start=281
  _JOINSPACEINPUT._serialized_end=359
  _JOINSPACEOUTPUT._serialized_start=361
  _JOINSPACEOUTPUT._serialized_end=411
  _REGISTERMEMBERINPUT._serialized_start=413
  _REGISTERMEMBERINPUT._serialized_end=482
  _REGISTERMEMBEROUTPUT._serialized_start=484
  _REGISTERMEMBEROUTPUT._serialized_end=506
  _LEAVESPACEINPUT._serialized_start=508
  _LEAVESPACEINPUT._serialized_end=525
  _LEAVESPACEOUTPUT._serialized_start=527
  _LEAVESPACEOUTPUT._serialized_end=545
  _ADDMEMBERINPUT._serialized_start=547
  _ADDMEMBERINPUT._serialized_end=605
  _ADDMEMBEROUTPUT._serialized_start=607
  _ADDMEMBEROUTPUT._serialized_end=657
  _UPDATEMEMBERINPUT._serialized_start=660
  _UPDATEMEMBERINPUT._serialized_end=919
  _UPDATEMEMBERINPUT_PATCH._serialized_start=800
  _UPDATEMEMBERINPUT_PATCH._serialized_end=919
  _UPDATEMEMBEROUTPUT._serialized_start=921
  _UPDATEMEMBEROUTPUT._serialized_end=941
  _REMOVEMEMBERINPUT._serialized_start=943
  _REMOVEMEMBERINPUT._serialized_end=981
  _REMOVEMEMBEROUTPUT._serialized_start=983
  _REMOVEMEMBEROUTPUT._serialized_end=1003
  _DESCRIBEMEMBERINPUT._serialized_start=1005
  _DESCRIBEMEMBERINPUT._serialized_end=1045
  _DESCRIBEMEMBEROUTPUT._serialized_start=1047
  _DESCRIBEMEMBEROUTPUT._serialized_end=1111
  _INTROSPECTMEMBERINPUT._serialized_start=1113
  _INTROSPECTMEMBERINPUT._serialized_end=1136
  _INTROSPECTMEMBEROUTPUT._serialized_start=1138
  _INTROSPECTMEMBEROUTPUT._serialized_end=1204
  _LISTMEMBERSINPUT._serialized_start=1207
  _LISTMEMBERSINPUT._serialized_end=1703
  _LISTMEMBERSINPUT_FILTER._serialized_start=1318
  _LISTMEMBERSINPUT_FILTER._serialized_end=1703
  _LISTMEMBERSOUTPUT._serialized_start=1705
  _LISTMEMBERSOUTPUT._serialized_end=1780
  _ADDMEMBERIDENTITYINPUT._serialized_start=1782
  _ADDMEMBERIDENTITYINPUT._serialized_end=1878
  _ADDMEMBERIDENTITYOUTPUT._serialized_start=1880
  _ADDMEMBERIDENTITYOUTPUT._serialized_end=1926
  _UPDATEMEMBERIDENTITYINPUT._serialized_start=1928
  _UPDATEMEMBERIDENTITYINPUT._serialized_end=2048
  _UPDATEMEMBERIDENTITYOUTPUT._serialized_start=2050
  _UPDATEMEMBERIDENTITYOUTPUT._serialized_end=2078
  _REMOVEMEMBERIDENTITYINPUT._serialized_start=2080
  _REMOVEMEMBERIDENTITYINPUT._serialized_end=2147
  _REMOVEMEMBERIDENTITYOUTPUT._serialized_start=2149
  _REMOVEMEMBERIDENTITYOUTPUT._serialized_end=2177
  _ADDATTRIBUTEINPUT._serialized_start=2179
  _ADDATTRIBUTEINPUT._serialized_end=2269
  _ADDATTRIBUTEOUTPUT._serialized_start=2271
  _ADDATTRIBUTEOUTPUT._serialized_end=2305
  _UPDATEATTRIBUTEINPUT._serialized_start=2307
  _UPDATEATTRIBUTEINPUT._serialized_end=2400
  _UPDATEATTRIBUTEOUTPUT._serialized_start=2402
  _UPDATEATTRIBUTEOUTPUT._serialized_end=2425
  _REMOVEATTRIBUTEINPUT._serialized_start=2427
  _REMOVEATTRIBUTEINPUT._serialized_end=2472
  _REMOVEATTRIBUTEOUTPUT._serialized_start=2474
  _REMOVEATTRIBUTEOUTPUT._serialized_end=2497
  _DESCRIBEATTRIBUTEINPUT._serialized_start=2499
  _DESCRIBEATTRIBUTEINPUT._serialized_end=2546
  _DESCRIBEATTRIBUTEOUTPUT._serialized_start=2548
  _DESCRIBEATTRIBUTEOUTPUT._serialized_end=2621
  _LISTATTRIBUTESINPUT._serialized_start=2624
  _LISTATTRIBUTESINPUT._serialized_end=2990
  _LISTATTRIBUTESINPUT_FILTER._serialized_start=2741
  _LISTATTRIBUTESINPUT_FILTER._serialized_end=2990
  _LISTATTRIBUTESOUTPUT._serialized_start=2992
  _LISTATTRIBUTESOUTPUT._serialized_end=3073
  _DESCRIBEIDENTITYPROVIDERINPUT._serialized_start=3075
  _DESCRIBEIDENTITYPROVIDERINPUT._serialized_end=3106
  _DESCRIBEIDENTITYPROVIDEROUTPUT._serialized_start=3108
  _DESCRIBEIDENTITYPROVIDEROUTPUT._serialized_end=3226
  _CONFIGUREIDENTITYPROVIDERINPUT._serialized_start=3228
  _CONFIGUREIDENTITYPROVIDERINPUT._serialized_end=3346
  _CONFIGUREIDENTITYPROVIDEROUTPUT._serialized_start=3348
  _CONFIGUREIDENTITYPROVIDEROUTPUT._serialized_end=3381
  _COMMUNITY._serialized_start=3384
  _COMMUNITY._serialized_end=6671
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class File(_message.Message):
    __slots__ = ["attributes", "created_at", "hash", "id", "path", "size", "type", "updated_at", "url"]
    class AttributesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    hash: str
    id: str
    path: str
    size: int
    type: str
    updated_at: _timestamp_pb2.Timestamp
    url: str
    def __init__(self, id: _Optional[str] = ..., path: _Optional[str] = ..., hash: _Optional[str] = ..., size: _Optional[int] = ..., type: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., attributes: _Optional[_Mapping[str, str]] = ..., url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/helpdesk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/helpdesk/helpdesk.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/helpdesk/document.proto\x1a!eolymp/wellknown/expression.proto\",\n\x15\x44\x65scribeDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeDocumentOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\x99\x02\n\x12ListDocumentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.helpdesk.ListDocumentsInput.Filter\x1a\xa7\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04path\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"N\n\x13ListDocumentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\"B\n\x13\x43reateDocumentInput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"+\n\x14\x43reateDocumentOutput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"W\n\x13UpdateDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\x12+\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\x16\n\x14UpdateDocumentOutput\"*\n\x13\x44\x65leteDocumentInput\x12\x13\n\x0b\x64ocument_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteDocumentOutput\"<\n\x11\x44\x65scribePathInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"A\n\x12\x44\x65scribePathOutput\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"\xfe\x01\n\x0eListPathsInput\x12\x19\n\x11preferred_locales\x18\x01 \x03(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.helpdesk.ListPathsInput.Filter\x1az\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12\x30\n\x04path\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x05label\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x0fListPathsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document\";\n\x10ListParentsInput\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\x02 \x03(\t\"L\n\x11ListParentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.helpdesk.Document2\xfa\n\n\x08Helpdesk\x12\xbc\x01\n\x10\x44\x65scribeDocument\x12&.eolymp.helpdesk.DescribeDocumentInput\x1a\'.eolymp.helpdesk.DescribeDocumentOutput\"W\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02#\x12!/helpdesk/documents/{document_id}\x12\xa4\x01\n\rListDocuments\x12#.eolymp.helpdesk.ListDocumentsInput\x1a$.eolymp.helpdesk.ListDocumentsOutput\"H\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x15\x12\x13/helpdesk/documents\x12\xa8\x01\n\x0e\x43reateDocument\x12$.eolymp.helpdesk.CreateDocumentInput\x1a%.eolymp.helpdesk.CreateDocumentOutput\"I\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x15\"\x13/helpdesk/documents\x12\xb6\x01\n\x0eUpdateDocument\x12$.eolymp.helpdesk.UpdateDocumentInput\x1a%.eolymp.helpdesk.UpdateDocumentOutput\"W\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x1a!/helpdesk/documents/{document_id}\x12\xb6\x01\n\x0e\x44\x65leteDocument\x12$.eolymp.helpdesk.DeleteDocumentInput\x1a%.eolymp.helpdesk.DeleteDocumentOutput\"W\x82\xe3\n\x1b\x8a\xe3\n\x17helpdesk:document:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#*!/helpdesk/documents/{document_id}\x12\xa4\x01\n\x0c\x44\x65scribePath\x12\".eolymp.helpdesk.DescribePathInput\x1a#.eolymp.helpdesk.DescribePathOutput\"K\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x17\x12\x15/helpdesk/lookup/path\x12\x9c\x01\n\tListPaths\x12\x1f.eolymp.helpdesk.ListPathsInput\x1a .eolymp.helpdesk.ListPathsOutput\"L\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x18\x12\x16/helpdesk/lookup/paths\x12\xa4\x01\n\x0bListParents\x12!.eolymp.helpdesk.ListParentsInput\x1a\".eolymp.helpdesk.ListParentsOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16helpdesk:document:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1a\x12\x18/helpdesk/lookup/parentsB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.helpdesk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _HELPDESK.methods_by_name['DescribeDocument']._options = None
  _HELPDESK.methods_by_name['DescribeDocument']._serialized_options = b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002#\022!/helpdesk/documents/{document_id}'
  _HELPDESK.methods_by_name['ListDocuments']._options = None
  _HELPDESK.methods_by_name['ListDocuments']._serialized_options = b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\025\022\023/helpdesk/documents'
  _HELPDESK.methods_by_name['CreateDocument']._options = None
  _HELPDESK.methods_by_name['CreateDocument']._serialized_options = b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\025\"\023/helpdesk/documents'
  _HELPDESK.methods_by_name['UpdateDocument']._options = None
  _HELPDESK.methods_by_name['UpdateDocument']._serialized_options = b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#\032!/helpdesk/documents/{document_id}'
  _HELPDESK.methods_by_name['DeleteDocument']._options = None
  _HELPDESK.methods_by_name['DeleteDocument']._serialized_options = b'\202\343\n\033\212\343\n\027helpdesk:document:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#*!/helpdesk/documents/{document_id}'
  _HELPDESK.methods_by_name['DescribePath']._options = None
  _HELPDESK.methods_by_name['DescribePath']._serialized_options = b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\027\022\025/helpdesk/lookup/path'
  _HELPDESK.methods_by_name['ListPaths']._options = None
  _HELPDESK.methods_by_name['ListPaths']._serialized_options = b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\030\022\026/helpdesk/lookup/paths'
  _HELPDESK.methods_by_name['ListParents']._options = None
  _HELPDESK.methods_by_name['ListParents']._serialized_options = b'\202\343\n\032\212\343\n\026helpdesk:document:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\032\022\030/helpdesk/lookup/parents'
  _DESCRIBEDOCUMENTINPUT._serialized_start=217
  _DESCRIBEDOCUMENTINPUT._serialized_end=261
  _DESCRIBEDOCUMENTOUTPUT._serialized_start=263
  _DESCRIBEDOCUMENTOUTPUT._serialized_end=332
  _LISTDOCUMENTSINPUT._serialized_start=335
  _LISTDOCUMENTSINPUT._serialized_end=616
  _LISTDOCUMENTSINPUT_FILTER._serialized_start=449
  _LISTDOCUMENTSINPUT_FILTER._serialized_end=616
  _LISTDOCUMENTSOUTPUT._serialized_start=618
  _LISTDOCUMENTSOUTPUT._serialized_end=696
  _CREATEDOCUMENTINPUT._serialized_start=698
  _CREATEDOCUMENTINPUT._serialized_end=764
  _CREATEDOCUMENTOUTPUT._serialized_start=766
  _CREATEDOCUMENTOUTPUT._serialized_end=809
  _UPDATEDOCUMENTINPUT._serialized_start=811
  _UPDATEDOCUMENTINPUT._serialized_end=898
  _UPDATEDOCUMENTOUTPUT._serialized_start=900
  _UPDATEDOCUMENTOUTPUT._serialized_end=922
  _DELETEDOCUMENTINPUT._serialized_start=924
  _DELETEDOCUMENTINPUT._serialized_end=966
  _DELETEDOCUMENTOUTPUT._serialized_start=968
  _DELETEDOCUMENTOUTPUT._serialized_end=990
  _DESCRIBEPATHINPUT._serialized_start=992
  _DESCRIBEPATHINPUT._serialized_end=1052
  _DESCRIBEPATHOUTPUT._serialized_start=1054
  _DESCRIBEPATHOUTPUT._serialized_end=1119
  _LISTPATHSINPUT._serialized_start=1122
  _LISTPATHSINPUT._serialized_end=1376
  _LISTPATHSINPUT_FILTER._serialized_start=1254
  _LISTPATHSINPUT_FILTER._serialized_end=1376
  _LISTPATHSOUTPUT._serialized_start=1378
  _LISTPATHSOUTPUT._serialized_end=1452
  _LISTPARENTSINPUT._serialized_start=1454
  _LISTPARENTSINPUT._serialized_end=1513
  _LISTPARENTSOUTPUT._serialized_start=1515
  _LISTPARENTSOUTPUT._serialized_end=1591
  _HELPDESK._serialized_start=1594
  _HELPDESK._serialized_end=2996
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.drive import file_pb2 as _file_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompleteMultipartUploadInput(_message.Message):
    __slots__ = ["parts", "upload_id"]
    class Part(_message.Message):
        __slots__ = ["checksum_sha1", "etag", "number"]
        CHECKSUM_SHA1_FIELD_NUMBER: _ClassVar[int]
        ETAG_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        checksum_sha1: str
        etag: str
        number: int
        def __init__(self, number: _Optional[int] = ..., etag: _Optional[str] = ..., checksum_sha1: _Optional[str] = ...) -> None: ...
    PARTS_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    parts: _containers.RepeatedCompositeFieldContainer[CompleteMultipartUploadInput.Part]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., parts: _Optional[_Iterable[_Union[CompleteMultipartUploadInput.Part, _Mapping]]] = ...) -> None: ...

class CompleteMultipartUploadOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateFileInput(_message.Message):
    __slots__ = ["attributes", "data", "path", "type"]
    class AttributesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.ScalarMap[str, str]
    data: bytes
    path: str
    type: str
    def __init__(self, path: _Optional[str] = ..., type: _Optional[str] = ..., attributes: _Optional[_Mapping[str, str]] = ..., data: _Optional[bytes] = ...) -> None: ...

class CreateFileOutput(_message.Message):
    __slots__ = ["file_id"]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file_id: str
    def __init__(self, file_id: _Optional[str] = ...) -> None: ...

class DeleteFileInput(_message.Message):
    __slots__ = ["file_id"]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file_id: str
    def __init__(self, file_id: _Optional[str] = ...) -> None: ...

class DeleteFileOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeFileInput(_message.Message):
    __slots__ = ["file_id"]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file_id: str
    def __init__(self, file_id: _Optional[str] = ...) -> None: ...

class DescribeFileOutput(_message.Message):
    __slots__ = ["file"]
    FILE_FIELD_NUMBER: _ClassVar[int]
    file: _file_pb2.File
    def __init__(self, file: _Optional[_Union[_file_pb2.File, _Mapping]] = ...) -> None: ...

class ListFilesInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["created_at", "hash", "id", "path", "size", "type", "updated_at"]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        HASH_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SIZE_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
        created_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        hash: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        size: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        updated_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., hash: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., size: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., created_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., updated_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListFilesInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListFilesInput.Filter, _Mapping]] = ...) -> None: ...

class ListFilesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...

class StartMultipartUploadInput(_message.Message):
    __slots__ = ["attributes", "path", "type"]
    class AttributesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.ScalarMap[str, str]
    path: str
    type: str
    def __init__(self, path: _Optional[str] = ..., type: _Optional[str] = ..., attributes: _Optional[_Mapping[str, str]] = ...) -> None: ...

class StartMultipartUploadOutput(_message.Message):
    __slots__ = ["upload_id"]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class UpdateFileInput(_message.Message):
    __slots__ = ["file", "file_id"]
    FILE_FIELD_NUMBER: _ClassVar[int]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file: _file_pb2.File
    file_id: str
    def __init__(self, file_id: _Optional[str] = ..., file: _Optional[_Union[_file_pb2.File, _Mapping]] = ...) -> None: ...

class UpdateFileOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UploadPartInput(_message.Message):
    __slots__ = ["data", "part_number", "upload_id"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    part_number: int
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., part_number: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadPartOutput(_message.Message):
    __slots__ = ["etag"]
    ETAG_FIELD_NUMBER: _ClassVar[int]
    etag: str
    def __init__(self, etag: _Optional[str] = ...) -> None: ...



from eolymp.executor import usage_pb2 as _usage_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Run(_message.Message):
    __slots__ = ["cpu_time_usage", "error", "exit_code", "id", "input", "input_ern", "lang", "memory_usage", "output", "output_ern", "problem_ern", "resource_usage", "runtime", "signal", "source", "source_ern", "status", "wall_time_usage"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CPU_EXHAUSTED: Run.Status
    CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR: Run.Status
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXECUTED: Run.Status
    EXECUTING: Run.Status
    EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
    FAILURE: Run.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    INPUT_ERN_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    MEMORY_OVERFLOW: Run.Status
    MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
    NONE: Run.Status
    OUTPUT_ERN_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    PENDING: Run.Status
    PROBLEM_ERN_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_FIELD_NUMBER: _ClassVar[int]
    SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT: Run.Status
    WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    cpu_time_usage: int
    error: str
    exit_code: int
    id: str
    input: str
    input_ern: str
    lang: str
    memory_usage: int
    output: str
    output_ern: str
    problem_ern: str
    resource_usage: _usage_pb2.ResourceUsage
    runtime: str
    signal: int
    source: str
    source_ern: str
    status: Run.Status
    wall_time_usage: int
    def __init__(self, id: _Optional[str] = ..., lang: _Optional[str] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., source_ern: _Optional[str] = ..., input: _Optional[str] = ..., input_ern: _Optional[str] = ..., status: _Optional[_Union[Run.Status, str]] = ..., error: _Optional[str] = ..., exit_code: _Optional[int] = ..., signal: _Optional[int] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[_Union[_usage_pb2.ResourceUsage, _Mapping]] = ..., output: _Optional[str] = ..., output_ern: _Optional[str] = ..., problem_ern: _Optional[str] = ...) -> None: ...



import os
import setuptools
import pathlib


for root, dirs, files in os.walk("./eolymp"):
    if os.path.basename(root) == "__pycache__":
        continue
    pathlib.Path(root + os.sep + "__init__.py").touch()

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="eolymp",
    version=os.getenv("RELEASE_VERSION"),
    author="Sergey Kolodyazhnyy",
    author_email="sergey@eolymp.com",
    description="Eolymp SDK for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/eolymp/contracts",
    packages=setuptools.find_packages(),
    package_data={package: ["py.typed", "*.pyi", "**/*.pyi"] for package in setuptools.find_packages()},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)
